@@ -20,15 +20,15 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #pragma once
 #include <list>
-#include <algorithm>
-#include <float.h>
-#include "../basic/match.h"
-#include "../basic/statistics.h"
-#include "../util/text_buffer.h"
-#include "../run/config.h"
-#include "../dp/flags.h"
-#include "../stats/cbs.h"
-#include "../output/def.h"
+#include <array>
+#include "basic/match.h"
+#include "basic/statistics.h"
+#include "util/text_buffer.h"
+#include "run/config.h"
+#include "dp/flags.h"
+#include "stats/cbs.h"
+#include "output/def.h"
+#include "basic/const.h"
 
 namespace Extension {
 
@@ -70,4 +70,4 @@ std::pair<std::vector<Match>, Stats> extend(BlockId query_id, Search::Hit* begin
 TextBuffer* generate_output(std::vector<Match> &targets, const Extension::Stats& stats, BlockId query_block_id, Statistics &stat, const Search::Config& cfg);
 TextBuffer* generate_intermediate_output(const std::vector<Match> &targets, BlockId query_block_id, const Search::Config& cfg);
 
-}
+}
\ No newline at end of file
