@@ -21,13 +21,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
 #include "seed_histogram.h"
-#include "../util/util.h"
-#include "../util/algo/partition.h"
-#include "../basic/shape_config.h"
+#include "util/algo/partition.h"
+#include "basic/shape_config.h"
 #include "block/block.h"
-#include "../util/ptr_vector.h"
-#include "enum_seeds.h"
+#include "util/ptr_vector.h"
 #include "seed_set.h"
+#include "data/enum_seeds.h"
 
 using std::vector;
 
@@ -39,7 +38,7 @@ SeedHistogram::SeedHistogram()
 size_t SeedHistogram::max_chunk_size(const int index_chunks) const
 {
 	size_t max = 0;
-	::Partition<int> p(Const::seedp, index_chunks);
+	::Partition<int> p(seedp(), index_chunks);
 	for (unsigned shape = 0; shape < shapes.count(); ++shape)
 		for (int chunk = 0; chunk < p.parts; ++chunk)
 			max = std::max(max, hst_size(data_[shape], SeedPartitionRange(p.begin(chunk), p.end(chunk))));
@@ -47,35 +46,32 @@ size_t SeedHistogram::max_chunk_size(const int index_chunks) const
 }
 
 template<typename Filter>
-SeedHistogram::SeedHistogram(Block& seqs, bool serial, const Filter* filter, EnumCfg& enum_cfg) :
-	data_(shapes.count()),
-	p_(seqs.seqs().partition(config.threads_))
+SeedHistogram::SeedHistogram(Block& seqs, bool serial, const Filter* filter, EnumCfg& enum_cfg, int seedp_bits) :
+	p_(seqs.seqs().partition(config.threads_)),
+	data_(shapes.count(), ShapeHistogram(p_.size() - 1, vector<unsigned>(seedp_count(seedp_bits), 0)))
 {
 	struct Callback {
-		Callback(size_t seqp, vector<ShapeHistogram>& data)
+		Callback(size_t seqp, int seedp_bits, vector<ShapeHistogram>& data):
+			seedp_mask(::seedp_mask(seedp_bits))
 		{
 			for (unsigned s = 0; s < shapes.count(); ++s)
 				ptr.push_back(data[s][seqp].data());
 		}
-		bool operator()(uint64_t seed, uint64_t pos, uint32_t block_id, size_t shape)
+		bool operator()(PackedSeed seed, uint64_t pos, uint32_t block_id, size_t shape)
 		{
-			++ptr[shape][seed_partition(seed)];
+			++ptr[shape][seed_partition(seed, seedp_mask)];
 			return true;
 		}
 		void finish() const
 		{
 		}
+		const PackedSeed seedp_mask;
 		vector<unsigned*> ptr;
 	};
 
-	for (unsigned s = 0; s < shapes.count(); ++s) {
-		data_[s].resize(p_.size() - 1);
-		for (std::array<unsigned, Const::seedp>& h : data_[s])
-			h.fill(0);
-	}
 	PtrVector<Callback> cb;
 	for (size_t i = 0; i < p_.size() - 1; ++i)
-		cb.push_back(new Callback(i, data_));
+		cb.push_back(new Callback(i, seedp_bits, data_));
 	enum_cfg.partition = &p_;
 	if (serial)
 		for (unsigned s = 0; s < shapes.count(); ++s) {
@@ -90,6 +86,6 @@ SeedHistogram::SeedHistogram(Block& seqs, bool serial, const Filter* filter, Enu
 	}
 }
 
-template SeedHistogram::SeedHistogram(Block&, bool, const NoFilter*, EnumCfg&);
-template SeedHistogram::SeedHistogram(Block&, bool, const SeedSet*, EnumCfg&);
-template SeedHistogram::SeedHistogram(Block&, bool, const HashedSeedSet*, EnumCfg&);
\ No newline at end of file
+template SeedHistogram::SeedHistogram(Block&, bool, const NoFilter*, EnumCfg&, int);
+template SeedHistogram::SeedHistogram(Block&, bool, const SeedSet*, EnumCfg&, int);
+template SeedHistogram::SeedHistogram(Block&, bool, const HashedSeedSet*, EnumCfg&, int);
\ No newline at end of file
