@@ -21,11 +21,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
 #pragma once
+#include <array>
+#include <stdint.h>
 #include <algorithm>
 #include <limits.h>
-#include "../util/simd.h"
-#include "../stats/score_matrix.h"
-#include "../util/simd/vector.h"
+#include "util/simd.h"
 
 namespace DISPATCH_ARCH {
 
