@@ -22,7 +22,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
 #pragma once
+#include <limits.h>
 #include "score_vector.h"
+#include "stats/score_matrix.h"
 
 namespace DISPATCH_ARCH {
 
@@ -845,4 +847,4 @@ static inline void set_channel(DISPATCH_ARCH::ScoreVector<int8_t, DELTA>& v, con
 	v.set(i, x);
 }
 
-#endif
+#endif
\ No newline at end of file
