@@ -20,7 +20,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #pragma once
 #include <ostream>
-#include "../../basic/match.h"
+#include "basic/match.h"
 
 FORCE_INLINE uint8_t cmp_mask(int x, int y) {
 	return x == y;
@@ -65,6 +65,9 @@ struct ForwardCell<int32_t> {
 	operator int32_t() const {
 		return v;
 	}
+	operator int32_t&() {
+		return v;
+	}
 	ForwardCell(const int32_t v) :
 		v(v),
 		ident(0),
@@ -123,6 +126,9 @@ struct BackwardCell<int32_t> {
 	operator int32_t() const {
 		return v;
 	}
+	operator int32_t& () {
+		return v;
+	}
 	BackwardCell(const int32_t v) :
 		v(v),
 		mismatch(0),
