@@ -19,9 +19,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <chrono>
 #include <thread>
 #include "output.h"
-#include "../data/queries.h"
-#include "../util/util.h"
-#include "../util/parallel/thread_pool.h"
+#include "util/util.h"
+#include "util/parallel/thread_pool.h"
 
 using std::chrono::high_resolution_clock;
 using std::chrono::seconds;
