@@ -1,9 +1,9 @@
 /****
 DIAMOND protein aligner
-Copyright (C) 2016-2020 Max Planck Society for the Advancement of Science e.V.
+Copyright (C) 2016-2024 Max Planck Society for the Advancement of Science e.V.
                         Benjamin Buchfink
 						
-Code developed by Benjamin Buchfink <benjamin.buchfink@tue.mpg.de>
+Code developed by Benjamin Buchfink <buchfink@gmail.com>
 Arm NEON port contributed by Martin Larralde <martin.larralde@embl.de>
 
 This program is free software: you can redistribute it and/or modify
@@ -21,8 +21,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
 #pragma once
-#include "../util/simd.h"
-#include "../basic/config.h"
+#include "util/simd.h"
+#include "basic/value.h"
 
 #ifdef __AVX2__
 
@@ -155,8 +155,4 @@ struct Byte_finger_print_48
 
 #endif
 
-#ifdef __AVX2__
-typedef Byte_finger_print_48 FingerPrint;
-#else
-typedef Byte_finger_print_48 FingerPrint;
-#endif
+typedef Byte_finger_print_48 FingerPrint;
\ No newline at end of file
