@@ -20,23 +20,19 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
 #pragma once
-#include <stddef.h>
 #include <vector>
-#include "../util/data_structures/flat_array.h"
-#include "../util/simd.h"
-#include "../dp/ungapped.h"
-#include "../basic/shape_config.h"
-#include "../basic/statistics.h"
-#include "../util/algo/pattern_matcher.h"
-#include "../util/scores/cutoff_table.h"
+#include "util/data_structures/flat_array.h"
+#include "basic/statistics.h"
+#include "util/algo/pattern_matcher.h"
 #include "finger_print.h"
-#include "../util/memory/alignment.h"
-#include "../run/config.h"
+#include "util/memory/alignment.h"
+#include "run/config.h"
 #include "hit.h"
-#include "../util/data_structures/writer.h"
-#include "../data/flags.h"
+#include "util/data_structures/writer.h"
+#include "data/flags.h"
 #include "kmer_ranking.h"
-#include "../util/algo/join_result.h"
+#include "util/algo/join_result.h"
+#include "basic/reduction.h"
 
 // #define UNGAPPED_SPOUGE
 
@@ -55,6 +51,12 @@ struct SensitivityTraits {
 	const double   default_block_size;
 	const Reduction& reduction;
 	const int      minimizer_window;
+#if WITH_DNA
+  const double   chain_fraction_align;
+  const int       min_chain_score;
+  const double max_overlap_extension;
+#endif
+  const int      sketch_size;
 };
 
 struct HashedSeedSet;
@@ -65,22 +67,23 @@ struct Context {
 	const PatternMatcher previous_matcher, current_matcher;
 	const int short_query_ungapped_cutoff;
 	KmerRanking* kmer_ranking;
+	const PackedSeed seedp_mask;
 };
 
-extern const std::map<Sensitivity, SensitivityTraits> sensitivity_traits[2];
-extern const std::map<Sensitivity, std::vector<std::string>> shape_codes[2];
-extern const std::map<Sensitivity, std::vector<Sensitivity>> iterated_sens;
-extern const std::map<Sensitivity, std::vector<Sensitivity>> cluster_sens;
+extern const std::map<Sensitivity, SensitivityTraits> sensitivity_traits;
+extern const std::map<Sensitivity, std::vector<std::string>> shape_codes;
+extern const std::map<Sensitivity, std::vector<Round>> iterated_sens;
 
 void search_shape(unsigned sid, int query_block, unsigned query_iteration, char* query_buffer, char* ref_buffer, Config& cfg, const HashedSeedSet* target_seeds);
 bool use_single_indexed(double coverage, size_t query_letters, size_t ref_letters);
 void setup_search(Sensitivity sens, Search::Config& cfg);
 MaskingAlgo soft_masking_algo(const SensitivityTraits& traits);
 bool keep_target_id(const Search::Config& cfg);
+int seedp_bits(int shape_weight, int threads, int index_chunks);
 
 }
 
-struct Stage1_hit
+/*struct Stage1_hit
 {
 	Stage1_hit(unsigned q_ref, unsigned q_offset, unsigned s_ref, unsigned s_offset) :
 		q(q_ref + q_offset),
@@ -98,11 +101,18 @@ struct Stage1_hit
 		}
 	};
 	unsigned q, s;
-};
+};*/
 
 namespace Search {
 
 struct WorkSet {
+	WorkSet(const Context& context, const Search::Config& cfg, unsigned shape_id, Writer<Hit>* out, KmerRanking *kmer_ranking):
+		context(context),
+		cfg(cfg),
+		shape_id(shape_id),
+		out(out),
+		kmer_ranking(kmer_ranking)
+	{}
 	Context context;
 	const Search::Config& cfg;
 	unsigned shape_id;
