@@ -18,8 +18,6 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
-#include <algorithm>
-#include <float.h>
 #include <queue>
 #include "algo.h"
 #include "../log_stream.h"
