@@ -21,7 +21,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #pragma once
 #include "../simd.h"
 
-#ifdef __SSE2__
+#if defined(__SSE2__) | defined(__ARM_NEON)
 #include "transpose16x16.h"
 #endif
 
@@ -31,4 +31,4 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #if ARCH_ID == 3
 static inline void transpose(const signed char** data, size_t n, signed char* out, const __m512i&) {}
-#endif
\ No newline at end of file
+#endif
